@@ -5,6 +5,7 @@ import win32api
 import win32con
 import time
 from random import choice
+from mouse import is_pressed as mouse_is_pressed
 from keyboard import is_pressed
 
 # VARS #
@@ -198,25 +199,14 @@ def play_recorded_movements(recording_name: str):
             print(FAIL + BOLD + f"Terminated Process As Failsafe Key '{failsafe_key}' Was Pressed." + END)
             log += "TERMINATED: process terminated due to failsafe activation.\n"
             quit()
+
         win32api.SetCursorPos(pos)
         time.sleep(0)
     log += f"RECORDING: finished playing recording {recording_name}\n"
 
 
-def is_clicked(mouse_button: int = 1, watch_time: int = 5) -> bool:
-    if mouse_button == 1:
-        b_num = 0x01
-    elif mouse_button == 2:
-        b_num = 0x02
-
-    start = time.time()
-    while 1:
-        if ctypes.windll.user32.GetKeyState(b_num) not in [0, 1]:
-            return True
-        elif time.time() - start >= watch_time:
-            break
-        time.sleep(0.001)
-    return False
+def is_clicked(mouse_button: str = "left") -> bool:
+    return mouse_is_pressed(button=mouse_button)
 
 
 class Log:
